@@ -4,6 +4,8 @@ __authors__ = ["Marek Pikuła <marek.pikula at embevity.com>"]
 
 from typing import TYPE_CHECKING
 
+from peakrdl.plugins.exporter import ExporterSubcommandPlugin  # type: ignore
+
 from .exporter import MarkdownExporter
 
 if TYPE_CHECKING:
@@ -13,10 +15,21 @@ if TYPE_CHECKING:
     from systemrdl.node import AddrmapNode, RootNode  # type: ignore
 
 
-class Exporter:  # pylint: disable=too-few-public-methods
+class Exporter(ExporterSubcommandPlugin):  # pylint: disable=too-few-public-methods
     """PeakRDL Markdown exporter plug-in."""
 
-    short_desc = "Export the register model to Markdown"
+    short_desc = "Generate Markdown documentation"
+    long_desc = "Export the register model to Markdown"
+
+    def add_exporter_arguments(self, arg_group: "argparse.ArgumentParser"):  # type: ignore
+        """Add PeakRDL exporter arguments."""
+        arg_group.add_argument(
+            "--depth",
+            dest="depth",
+            default=0,
+            type=int,
+            help="Depth of generation (0 means all)",
+        )
 
     def do_export(
         self, top_node: "Union[AddrmapNode, RootNode]", options: "argparse.Namespace"
@@ -32,4 +45,5 @@ class Exporter:  # pylint: disable=too-few-public-methods
             options.output,
             input_files=options.input_files,
             rename=options.inst_name,
+            depth=options.depth,
         )
