@@ -91,7 +91,16 @@ class MarkdownExporter:  # pylint: disable=too-few-public-methods
             node -- node to generate the header for.
             heading_level -- Markdown heading level.
         """
-        ret = self._heading(heading_level, node.inst_name)
+        if isinstance(node, AddrmapNode):
+            node_type_name = "address map"
+        elif isinstance(node, RegfileNode):
+            node_type_name = "register file"
+        elif isinstance(node, RegNode):
+            node_type_name = "register"
+        else:
+            node_type_name = "addressable node"
+
+        ret = self._heading(heading_level, f"{node.inst_name} {node_type_name}")
         ret += self._addrnode_info_md(node) + "\n\n"
         desc = node.get_html_desc()
         if desc is not None:
@@ -120,12 +129,13 @@ class MarkdownExporter:  # pylint: disable=too-few-public-methods
 
         return table_row
 
-    def export(
+    def export(  # pylint: disable=too-many-arguments
         self,
         node: Union[AddrmapNode, RootNode],
         output_path: str,
         input_files: Optional[List[str]] = None,
         rename: Optional[str] = None,
+        depth: int = 0,
     ):
         """Export the `node` to generated Python interface file.
 
@@ -134,6 +144,7 @@ class MarkdownExporter:  # pylint: disable=too-few-public-methods
             input_files -- list of input files.
             output_path -- path to the exported file.
             rename -- name to rename the top-level to.
+            depth -- depth of generation (0 means all)
         """
         # Get the top node.
         top = node.top if isinstance(node, RootNode) else node
@@ -141,7 +152,7 @@ class MarkdownExporter:  # pylint: disable=too-few-public-methods
 
         generated_from = top_name
         if input_files is not None:
-            generated_from = "  " + ("\n" + "  ").join(f for f in input_files)
+            generated_from += "\n  - " + "\n  - ".join(f for f in input_files)
 
         # Ensure proper format of the output path and that the directory exists.
         if not output_path.endswith(".md"):
@@ -149,7 +160,7 @@ class MarkdownExporter:  # pylint: disable=too-few-public-methods
         Path(output_path).parent.mkdir(parents=True, exist_ok=True)
 
         # Run generation.
-        gen = self._add_addrmap_regfile(top, node.env.msg).generated
+        gen = self._add_addrmap_regfile(top, node.env.msg, depth - 1).generated
 
         # Write to the file.
         with open(output_path, "w", encoding="UTF-8") as output:
@@ -165,12 +176,14 @@ class MarkdownExporter:  # pylint: disable=too-few-public-methods
         self,
         node: Union[AddrmapNode, RegfileNode],
         msg: MessageHandler,
+        depth: int,
     ) -> GenStageOutput:
         """Generate addrmap or regfile.
 
         Arguments:
             node -- RegfileNode or AddrmapNode.
             msg -- message handler from top-level.
+            depth -- depth of generation left.
 
         Keyword Arguments:
             is_top -- if the current not is the top node. If True the
@@ -183,7 +196,7 @@ class MarkdownExporter:  # pylint: disable=too-few-public-methods
         member_gen: str = ""
         for child in node.children(unroll=True, skip_not_present=False):
             if isinstance(child, (AddrmapNode, RegfileNode)):
-                output = self._add_addrmap_regfile(child, msg)
+                output = self._add_addrmap_regfile(child, msg, depth - 1)
                 member_gen += output.generated
                 members.append(output)
             elif isinstance(child, RegNode):
@@ -220,7 +233,9 @@ class MarkdownExporter:  # pylint: disable=too-few-public-methods
         gen += "\n"
 
         return MarkdownExporter.GenStageOutput(
-            node, self._addrnode_table_row(node), gen + member_gen
+            node,
+            self._addrnode_table_row(node),
+            gen + (member_gen if depth != 0 else ""),
         )
 
     def _add_reg(self, node: RegNode, msg: MessageHandler) -> GenStageOutput:
@@ -297,6 +312,6 @@ class MarkdownExporter:  # pylint: disable=too-few-public-methods
         gen = ""
         desc = node.get_html_desc()
         if desc is not None:
-            gen = self._heading(4, node.inst_name) + desc + "\n"
+            gen = self._heading(4, f"{node.inst_name} field") + desc + "\n"
 
         return MarkdownExporter.GenStageOutput(node, table_row, gen)
